# geoint-py
A bunch of geospatial intelligence workflows implemented using Python.

## Features
- Create a rectangular spatial grid for binning

![spatial_binning](https://github.com/gisfromscratch/geoint-py/raw/main/spatial_bin.png)
© GDI-TH, Esri, HERE, Garmin, FAO, NOAA, USGS - Powered by Esri

## Usage
Take a look at the [sample](https://github.com/gisfromscratch/geoint-py/blob/main/Samples.ipynb) jupyter notebook.

## References
- [ArcGIS API for Python](https://developers.arcgis.com/python/)

### Geospatial Intelligence Publications
- [Geospatial Intelligence @ Medium](https://medium.com/geospatial-intelligence)
